@@ -93,3 +93,8 @@ def calcRectByImageBytes(image, boxs=[], padding=20, areaThreshold=900):
     arr = np.asarray(bytearray(image), dtype="uint8")
     img = cv2.imdecode(arr, cv2.IMREAD_COLOR)
     return calcRectByImage(img, boxs, padding, areaThreshold)
+
+# 图片框校准,source 是图片文件路径
+def calcRectByImagePath(source, boxs=[], padding=20, areaThreshold=900):
+    img = img0 = cv2.imread(source)
+    return calcRectByImage(img, boxs, padding, areaThreshold)
